==> nuke-number-picker-2.0.2.tgz: package/src/styles/index.js <==
'use strict';

import VariableFactory from './variable';

function styleProvider(theme = {}) {
  const Variables = VariableFactory(theme);
  const core = theme.Core;
  return {
    NumberPicker: {
      'number-picker': {
        // flex: 1,
        flexDirection: 'row',
        height: Variables['button-height'],
      },
      'input-wrap': {
        margin: 0,
        outline: 0,
        // alignSelf: 'center',
        borderRadius: 0,
        textAlign: 'center',
        boxShadow: 'none',
        // width: Variables['input-min-width'],
        height: Variables['button-height'],
        color: Variables['input-color'],
        flex: 1,
        // minWidth: Variables['input-min-width'],

        paddingLeft: 0,
        paddingRight: 0,
        fontSize: Variables['input-size-text'],
        backgroundColor: Variables['input-bg-color'],
        ...core.border(
          Variables['border-width'],
          Variables['border-style'],
          Variables['border-color']
        ),
      },

      'input-disabled': {
        backgroundColor: Variables['input-bg-color-disabled'],
        color: Variables['input-color-disabled'],
      },
      input: {
        // color:'yellow',

        WebkitAppearance: 'none',
        alignItems: 'center',
        textAlign: 'center',
        justifyContent: 'center',
      },
      reduce: {
        justifyContent: 'center',
        alignItems: 'center',
        width: Variables['button-width'],
        height: Variables['button-height'],
        backgroundColor: Variables['button-bg-color'],
        'backgroundColor:active': Variables['button-bg-color-active'],
        ...core.border(
          Variables['border-width'],
          Variables['border-style'],
          Variables['border-color']
        ),
      },
      icon: {
        fontSize: Variables['icon-size'],
        color: Variables['icon-color'],
      },
      add: {
        justifyContent: 'center',
        alignItems: 'center',
        width: Variables['button-width'],
        height: Variables['button-height'],
        backgroundColor: Variables['button-bg-color'],
        'backgroundColor:active': Variables['button-bg-color-active'],
        ...core.border(
          Variables['border-width'],
          Variables['border-style'],
          Variables['border-color']
        ),
      },

      'icon-disabled': {
        color: Variables['icon-color-disabled'],
      },
      'disabled-button': {
        backgroundColor: Variables['button-bg-color-disabled'],
        'backgroundColor:active': Variables['button-bg-color-disabled'],
      },
      'error-input-wrap': {
        borderColor: Variables['input-border-color-error'],
      },
      'error-input': {
        color: Variables['input-color-error'],
      },
    },
  };
}
module.exports = styleProvider;

==> nuke-number-picker-2.0.7.tgz: package/src/styles/index.js <==
'use strict';

import VariableFactory from './variable';

function styleProvider(theme = {}) {
  const Variables = VariableFactory(theme);
  const core = theme.Core;
  return {
    NumberPicker: {
      'number-picker': {
        // flex: 1,
        flexDirection: 'row',
        height: Variables['button-height'],
      },
      'input-wrap': {
        outline: 0,
        // alignSelf: 'center',
        borderRadius: 0,
        textAlign: 'center',
        boxShadow: 'none',
        // width: Variables['input-min-width'],
        height: Variables['button-height'],
        color: Variables['input-color'],
        flex: 1,
        // minWidth: Variables['input-min-width'],

        paddingLeft: 0,
        paddingRight: 0,

        fontSize: Variables['input-size-text'],
        backgroundColor: Variables['input-bg-color'],
        borderWidth: Variables['input-border-width'],
        borderStyle: Variables['input-border-style'],
        borderColor: Variables['input-border-color'],
        marginLeft: -1,

      },

      'input-disabled': {
        backgroundColor: Variables['input-bg-color-disabled'],
        color: Variables['input-color-disabled'],
      },
      input: {
        // color:'yellow',

        WebkitAppearance: 'none',
        alignItems: 'center',
        textAlign: 'center',
        justifyContent: 'center',
      },
      reduce: {
        justifyContent: 'center',
        alignItems: 'center',
        width: Variables['button-width'],
        height: Variables['button-height'],
        backgroundColor: Variables['button-bg-color'],
        'backgroundColor:active': Variables['button-bg-color-active'],
        ...core.border(
          Variables['button-border-width'],
          Variables['button-border-style'],
          Variables['button-border-color']
        ),
        marginRight: -1,
      },
      icon: {
        fontSize: Variables['icon-size'],
        color: Variables['icon-color'],
      },
      add: {
        justifyContent: 'center',
        alignItems: 'center',
        width: Variables['button-width'],
        height: Variables['button-height'],
        backgroundColor: Variables['button-bg-color'],
        'backgroundColor:active': Variables['button-bg-color-active'],
        ...core.border(
          Variables['button-border-width'],
          Variables['button-border-style'],
          Variables['button-border-color']
        ),
        marginLeft: -1,
      },

      'icon-disabled': {
        color: Variables['icon-color-disabled'],
      },
      'disabled-button': {
        backgroundColor: Variables['button-bg-color-disabled'],
        'backgroundColor:active': Variables['button-bg-color-disabled'],
      },
      'error-input-wrap': {
        borderColor: Variables['input-border-color-error'],
      },
      'error-input': {
        color: Variables['input-color-error'],
      },
    },
  };
}
module.exports = styleProvider;
